@@ -133,14 +133,11 @@ class Visualization:
         self.time_series_field_ids = self.time_series.get("fields", [])
         self.thresholds = self.visualization.get("thresholds", {})
         self.thresholds_field_ids = self.thresholds.get("fields", [])
-        self.calculated_time_series = self.visualization.get("calculatedTimeSeries", {})
-        self.calculated_time_series_tags = self.calculated_time_series.get("tags", [])
 
     def to_dict(self):
         convert = {
             "timeSeries": {"fields": self.time_series_field_ids},
             "thresholds": {"fields": self.thresholds_field_ids},
-            "calculatedTimeSeries": {"tags": self.calculated_time_series_tags},
         }
         return convert
 
