@@ -32,7 +32,7 @@ def zip_and_upload(client: CogniteClient, code_path: Path, file_name: str, data_
         file = client.files.upload(
             f"{zip_path}.zip",
             name=f"{file_name}.zip",
-            external_id=file_name,
+            external_id=f"{file_name}.zip",
             overwrite=True,
             data_set_id=id,
         )
