@@ -42,8 +42,10 @@ def deploy_function(
     owner: str = "",
 ) -> None:
     delete_function_if_exists(client, function_name)
-
+    print("formatting secret names")
+    print([i for i in secrets.keys()])
     secrets = format_secret_names(secrets)
+    print([i for i in secrets.keys()])
     print("Deploying function ...", flush=True)
     x = 0
     while x < 3:
