@@ -1,6 +1,6 @@
 import os
 import sys
-from pathlib import Path, PosixPath
+from pathlib import Path
 from typing import Dict
 
 from ruamel.yaml import YAML
@@ -16,7 +16,7 @@ def load_yaml(path: Path) -> Dict:
 
 
 working_path = env.get_env_value("PWD")
-ROOT_DIR = PosixPath(working_path)
+ROOT_DIR = Path(working_path)
 FUNCTIONS_PATH = ROOT_DIR / "functions"
 IGNORE_MODELS_PATH = ROOT_DIR / ".ignore_models"
 
